@@ -1,16 +1,15 @@
 import os
+from typing import Any, Dict, List, Optional, Tuple, Union
+
+import ipywidgets as widgets
 import numpy as np
 import pandas as pd
-import ipywidgets as widgets
 from IPython.display import display
-
-from .basemaps import xyz_to_plotly
-from . import common
-from . import osm
-from . import examples
-from typing import Optional, List, Union, Dict, Tuple
 from pandas import DataFrame
 
+from . import common, examples, osm
+from .basemaps import xyz_to_plotly
+
 try:
     import plotly.express as px
     import plotly.graph_objects as go
@@ -221,7 +220,7 @@ class Map(go.FigureWidget):
         """Adds a mapbox layer to the map.
 
         Args:
-            layer (str | dict): Layer to add. Can be "basic", "streets", "outdoors", "light", "dark", "satellite", or "satellite-streets". See https://plotly.com/python/mapbox-layers/ and https://docs.mapbox.com/mapbox-gl-js/style-spec/
+            style (str | dict): Style to add. Can be "basic", "streets", "outdoors", "light", "dark", "satellite", or "satellite-streets". See https://plotly.com/python/mapbox-layers/ and https://docs.mapbox.com/mapbox-gl-js/style-spec/
             access_token (str, optional): The Mapbox Access token. It can be set as an environment variable "MAPBOX_TOKEN". Defaults to None.
         """
 
@@ -408,7 +407,7 @@ class Map(go.FigureWidget):
         opacity: Optional[float] = 1.0,
         bands: Optional[List] = None,
         titiler_endpoint: Optional[str] = None,
-        **kwargs,
+        **kwargs: Any,
     ) -> None:
         """Adds a COG TileLayer to the map.
 
@@ -424,6 +423,9 @@ class Map(go.FigureWidget):
                 and https://cogeotiff.github.io/rio-tiler/colormap/. To select a certain bands, use bidx=[1, 2, 3].
                 apply a rescaling to multiple bands, use something like `rescale=["164,223","130,211","99,212"]`.
         """
+        if os.environ.get("USE_MKDOCS") is not None:
+            return
+
         tile_url = common.cog_tile(url, bands, titiler_endpoint, **kwargs)
         center = common.cog_center(url, titiler_endpoint)  # (lon, lat)
         self.add_tile_layer(tile_url, name, attribution, opacity)
@@ -581,6 +583,7 @@ class Map(go.FigureWidget):
         """
         common.check_package("geopandas")
         import json
+
         import geopandas as gpd
 
         gdf = gpd.read_file(data).to_crs(epsg=4326)
@@ -780,13 +783,14 @@ class Map(go.FigureWidget):
         """Prepare proper and give style for different type of Geometry
 
         Args:
-            in_geojson (str | dict): The file path or http URL to the input GeoJSON or a dictionary containing the geojson.
+            geojson_in (str | dict): The file path or http URL to the input GeoJSON or a dictionary containing the geojson.
             name (str): Name for the Layer
             color (str, optional): Plain name for color (e.g: blue) or color code (e.g: #FF0000)
             opacity(float, optional): opacity of the layer in Map
         """
 
         import json
+
         import requests
 
         if isinstance(geojson_in, dict):
@@ -852,8 +856,8 @@ def fix_widget_error() -> None:
     Fix FigureWidget - 'mapbox._derived' Value Error.
     Adopted from: https://github.com/plotly/plotly.py/issues/2570#issuecomment-738735816
     """
-    import shutil
     import importlib.resources
+    import shutil
 
     pkg_dir = os.path.dirname(importlib.resources.files("plotly") / "plotly.py")
 
